==> mgb-0.6.4.tar.bz2: language/lang_italian_utf8/lang_import.php <==
<?php
	
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2007 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// =============================== //
	// lang_italian.php - Italiano 1.0 //
	// =============================== //
	//
	// This language file was translated by Christian Castelli alias VooDoo (voodoo81people@gmail.com) 
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //
	
	// header
	$lang['h_title'] = "Importazioni di dati da una versione precedente";
	
	// general
	$lang['next_step'] = "&raquo; continua &raquo;";
	$lang['yes'] = "yes";
	$lang['no'] = "no";
	$lang['active'] = "attivo";
	$lang['inactive'] = "inattivo";
	$lang['ok'] = "OK!";
	$lang['not_ok'] = "fallito!";
		
	// installation
	$lang['title'] = "Importazioni di dati da una versione precedente";
	
	$lang['expl_import'] = "Per favore fornisci i dettagli di connessione al database nel quale la vecchia installazione di MGB è presente. In alternativa dovresti fornire il percorso assoluto alla vecchia installazione <b>senza il nome di dominio</b>. Esempio: invece di <i>http://www.example.com/php/mgb/</i> solo <i>/php/mgb/</i>. Attenzione alle slash all'inizio e alla fine.";
	
	// step 1
	$lang['db_title'] = "Dettagli del database:";
	$lang['db_hostname'] = "host:";
	$lang['db_dbname'] = "Nome del database:";
	$lang['db_username'] = "username:";
	$lang['db_password'] = "password:";
	$lang['oldgb_path'] = "percorso:";
	$lang['import_settings'] = "settaggi d'importazione:";
	
	// errormessages step 1
	$lang['no_error'] = "tutti i valori forniti sono OK!";
	$lang['error_1_step1'] = "per favore riempi tutti i campi!";
	$lang['error_2_step1'] = "non può essere stabilita una connessione al database, per favore controlla i dati di login!";
	$lang['error_3_step1'] = "Al percorso fornito non è stata trovata alcuna installazione di MGB!";
	$lang['error_4_step1'] = "Il database indicato è OK, ma non è stata trovata alcuna installazione precedente!";
	
	// step 2
	$lang['transfer_settings'] = "Settaggi di trasferimento...";
	$lang['transfer_entries'] = "Dati di trasferimento...";
	
	// finish
	$lang['import_finish'] = "Congratulazioni!<br><br>I dati della tua vecchia installazione di MGB sono stati portati con successo alla versione ".MGB_VERSION.". <br><br><a href='../admin/admin.php' title='to the administration'>Torna al pannello di amministrazione</a><br><a href='../index.php' title='to the guestbook'>Torna al guestbook</a>";
?>

==> mgb-0.6.5.tar.bz2: language/lang_italian_utf8/lang_import.php <==
<?php
	
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ============================= //
	// lang_import.php - Italian 1.0 //
	// ============================= //
	//
	// This language file was translated by Christian Castelli alias VooDoo (voodoo81people@gmail.com) 
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //
	
	// header
	$lang['h_title'] = "Importazioni di dati da una versione precedente";
	
	// general
	$lang['next_step'] = "&raquo; continua &raquo;";
	$lang['yes'] = "yes";
	$lang['no'] = "no";
	$lang['active'] = "attivo";
	$lang['inactive'] = "inattivo";
	$lang['ok'] = "OK!";
	$lang['not_ok'] = "fallito!";
		
	// installation
	$lang['title'] = "Importazioni di dati da una versione precedente";
	
	$lang['expl_import'] = "Per favore fornisci i dettagli di connessione al database nel quale la vecchia installazione di MGB è presente. In alternativa dovresti fornire il percorso assoluto alla vecchia installazione <b>senza il nome di dominio</b>. Esempio: invece di <i>http://www.example.com/php/mgb/</i> solo <i>/php/mgb/</i>. Attenzione alle slash all'inizio e alla fine.";
	
	// step 1
	$lang['db_title'] = "Dettagli del database:";
	$lang['db_hostname'] = "host:";
	$lang['db_dbname'] = "Nome del database:";
	$lang['db_username'] = "username:";
	$lang['db_password'] = "password:";
	$lang['oldgb_path'] = "percorso:";
	$lang['import_settings'] = "settaggi d'importazione:";
	
	// errormessages step 1
	$lang['no_error'] = "tutti i valori forniti sono OK!";
	$lang['error_1_step1'] = "per favore riempi tutti i campi!";
	$lang['error_2_step1'] = "non può essere stabilita una connessione al database, per favore controlla i dati di login!";
	$lang['error_3_step1'] = "Al percorso fornito non è stata trovata alcuna installazione di MGB!";
	$lang['error_4_step1'] = "Il database indicato è OK, ma non è stata trovata alcuna installazione precedente!";
	
	// step 2
	$lang['transfer_settings'] = "Settaggi di trasferimento...";
	$lang['transfer_entries'] = "Dati di trasferimento...";
	
	// finish
	$lang['import_finish'] = "Congratulazioni!<br><br>I dati della tua vecchia installazione di MGB sono stati portati con successo alla versione ".MGB_VERSION.". <br><br><a href='../admin/admin.php' title='to the administration'>Torna al pannello di amministrazione</a><br><a href='../index.php' title='to the guestbook'>Torna al guestbook</a>";
?>
